@@ -79,7 +79,7 @@
 # Make version info available
 __ver_major__ = 1
 __ver_minor__ = 5
-__ver_patch__ = 0
+__ver_patch__ = 2
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
@@ -1167,7 +1167,44 @@ class TestInstallEnv(unittest.TestCase):
         self.install()
         self.runtests()
 
+
+class TestPy2exe(unittest.TestCase):
+    """Run all testcases inside a py2exe executable"""
+   
+    def setUp(self):
+        self._tempDir = self._mkdtemp()
     
+    def tearDown(self):
+        import shutil
+        shutil.rmtree(self._tempDir)
+
+    def test_py2exe(self):
+        """Testing pyenchant running inside a py2exe executable."""
+        import os, sys, shutil
+        from os import path
+        from os.path import dirname
+        try:
+            import py2exe
+        except ImportError:
+            return
+        os.environ["PYTHONPATH"] = dirname(dirname(__file__))
+        setup_py = path.join(dirname(__file__),"..","tools","setup.py2exe.py")
+        if not path.exists(setup_py):
+            return
+        buildCmd = '%s %s -q py2exe --dist-dir="%s"'
+        buildCmd = buildCmd % (sys.executable,setup_py,self._tempDir)
+        res = os.system(buildCmd)
+        self.assertEqual(res,0)
+        testCmd = self._tempDir + "\\test_pyenchant.exe"
+        self.assertTrue(os.path.exists(testCmd))
+        res = os.system(testCmd)
+        self.assertEqual(res,0)
+        
+    def _mkdtemp(self):
+        """Simple wrapper for tempfile.mkdtemp"""
+        import tempfile
+        return tempfile.mkdtemp()
+
 
 def testsuite(recurse=True):
     from enchant.checker import TestChecker
@@ -1176,6 +1213,7 @@ def testsuite(recurse=True):
     suite = unittest.TestSuite()
     if recurse:
       suite.addTest(unittest.makeSuite(TestInstallEnv))
+      suite.addTest(unittest.makeSuite(TestPy2exe))
     suite.addTest(unittest.makeSuite(TestBroker))
     suite.addTest(unittest.makeSuite(TestDict))
     suite.addTest(unittest.makeSuite(TestPWL))
