@@ -42,6 +42,7 @@
 """
 
 import os
+import sys
 
 # Attempt to access local language information
 try:
@@ -119,21 +120,23 @@ class EnchantStr(str):
     objects will be unicode by default.
     """
 
-    def __new__(self,value):
+    def __new__(cls,value):
         """EnchantStr data constructor.
 
         This method records whether the initial string was unicode, then
         simply passes it along to the default string constructor.
         """
         if type(value) is unicode:
-          self._was_unicode = True
+          was_unicode = True
           if str is not unicode:
             value = value.encode("utf-8")
         else:
-          self._was_unicode = False
+          was_unicode = False
           if str is not bytes:
             raise RuntimeError("Don't pass bytestrings to pyenchant")
-        return str.__new__(self,value)
+        self = str.__new__(cls,value)
+        self._was_unicode = was_unicode
+        return self
 
     def encode(self):
         """Encode this string into a form usable by the enchant C library."""
@@ -196,8 +199,15 @@ def get_resource_filename(resname):
     path = os.path.join(path,resname)
     if os.path.exists(path):
         return path
-    import pkg_resources
-    return pkg_resources.resource_filename("enchant",resname)
+    if hasattr(sys, "frozen"):
+        exe_dir = os.path.dirname(unicode(sys.executable,sys.getfilesystemencoding()))
+        path = os.path.join(exe_dir, resname)
+        if os.path.exists(path):
+            return path
+    else:
+        import pkg_resources
+        return pkg_resources.resource_filename("enchant",resname)
+    raise RuntimeError("Could not locate resource '%s'" % (resname,))
 
 
 def win32_data_files():
@@ -212,9 +222,22 @@ def win32_data_files():
     Only really tested on the win32 platform (it's the only platform for
     which we ship our own supporting data files)
     """
+    #  Include the main enchant DLL
+    libEnchant = get_resource_filename("libenchant.dll")
+    mainDir = os.path.dirname(libEnchant)
+    dataFiles = [('',[libEnchant])]
+    #  And some specific supporting DLLs
+    for dll in os.listdir(mainDir):
+        if not dll.endswith(".dll"):
+            continue
+        for prefix in ("iconv","intl","libglib","libgmodule"):
+            if dll.startswith(prefix):
+                break
+        else:
+            continue
+        dataFiles[0][1].append(os.path.join(mainDir,dll))
+    #  And anything found in the supporting data directories
     dataDirs = ("share/enchant/myspell","share/enchant/ispell","lib/enchant")
-    mainDir = os.path.dirname(get_resource_filename("libenchant.dll"))
-    dataFiles = []
     for dataDir in dataDirs:
         files = []
         fullDir = os.path.join(mainDir,os.path.normpath(dataDir))
